#include <stdio.h>
#include <stdlib.h>

struct container {
  int count, size, start;
  int *a;
};

typedef struct container * array_container;

array_container make_array_container() {
  array_container ac;

  ac = (array_container)malloc(sizeof(struct container));
  ac->count = 0;
  ac->start = 0;
  ac->size = 1;
  ac->a = (int*)malloc(ac->size * sizeof(int));

  return ac;
}

void copy_array(int* to, int* from, int len) {
  int i;
  for (i = len; i-- > 0; ) {
    to[i] = from[i];
  }
}

void maybe_grow_array(array_container ac) {
  int *new_a;
  if (ac->count >= ac->size) {
    new_a = (int*)malloc(ac->size * 2 * sizeof(int));
    if (ac->start + ac->count < ac->size) {
      copy_array(new_a, ac->a + ac->start, ac->count);
    } else {
      int c1 = ac->size - ac->start;
      copy_array(new_a, ac->a + ac->start, c1);
      copy_array(new_a + c1, ac->a, ac->count - c1);
    }
    ac->size *= 2;
    ac->start = 0;
    ac->a = new_a;
  }
}

void add_to_front(array_container ac, int i) {
  maybe_grow_array(ac);

  --ac->start;
  if (ac->start < 0)
    ac->start = ac->start + ac->size;
  ac->a[ac->start] = i;
  ac->count++;
}

void add_to_back(array_container ac, int i) {
  maybe_grow_array(ac);
  
  ac->a[(ac->start + ac->count) % ac->size] = i;
  ac->count++;
}

int remove_from_front(array_container ac) {
  int i;

  i = ac->a[ac->start];
  ac->start++;
  if (ac->start >= ac->size)
    ac->start = ac->start - ac->size;
  --ac->count;

  return i;
}

int remove_from_back(array_container ac) {
  int i;

  i = ac->a[(ac->start + ac->count - 1) % ac->size];
  --ac->count;

  return i;
}

int get_count(array_container ac) {
  return ac->count;
}

int get_value(array_container ac, int i) {
  return ac->a[(i + ac->start) % ac->size];
}

/* ---------------------------------------- */

/* Tests */

void failed() {
  printf("test failed\n");
  exit(1);
}

void check_ptr(void *a, void *b) {
  if (a != b) failed();
}

void check_int(int a, int b) {
  if (a != b) failed();
}

void test() {
  array_container ac;
  int i, j;

  ac = make_array_container();
  check_int(get_count(ac), 0);
  add_to_front(ac, 5);
  check_int(get_count(ac), 1);
  check_int(get_value(ac, 0), 5);
  add_to_back(ac, 6);
  check_int(get_count(ac), 2);
  check_int(get_value(ac, 0), 5);
  check_int(get_value(ac, 1), 6);
  add_to_back(ac, 7);
  add_to_front(ac, 4);
  check_int(get_count(ac), 4);
  check_int(get_value(ac, 0), 4);
  check_int(get_value(ac, 1), 5);
  check_int(get_value(ac, 2), 6);
  check_int(get_value(ac, 3), 7);

  /* Check behavior as a queue: */
  ac = make_array_container();
  for (i = 0; i < 100; i++) {
    for (j = 0; j < i; j++)
      add_to_front(ac, j);
    check_int(get_count(ac), i);
    for (j = 0; j < i; j++)
      check_int(remove_from_back(ac), j);

    check_int(get_count(ac), 0);

    for (j = 0; j < i; j++)
      add_to_back(ac, j);
    check_int(get_count(ac), i);
    for (j = 0; j < i; j++)
      check_int(remove_from_front(ac), j);
  }

  /* Check behavior as a stack: */
  ac = make_array_container();
  for (i = 0; i < 100; i++) {
    for (j = 0; j < i; j++)
      add_to_front(ac, j);
    check_int(get_count(ac), i);
    for (j = i; j-- > 0; )
      check_int(remove_from_front(ac), j);

    check_int(get_count(ac), 0);

    for (j = 0; j < i; j++)
      add_to_back(ac, j);
    check_int(get_count(ac), i);
    for (j = i; j-- > 0; )
      check_int(remove_from_back(ac), j);
  }
}

/* ---------------------------------------- */

int main() {
  array_container ac;
  char buffer[256];
  int i, count, back;

  test();

  ac = make_array_container();
  
  for (back = 1; fgets(buffer, 256, stdin); back = !back) {
    if (back)
      add_to_back(ac, atoi(buffer));
    else
      add_to_front(ac, atoi(buffer));
  }

  count = get_count(ac);
  for (i = 0; i < count; i++) {
    back = !back;
    if (back)
      printf("%d\n", remove_from_back(ac));
    else
      printf("%d\n", remove_from_front(ac));
  }

  return 0;
}
