#include <stdio.h>
#include <stdlib.h>

struct container {
  int count, size;
  int *a;
};

typedef struct container * array_container;

array_container make_array_container() {
  array_container ac;

  ac = (array_container)malloc(sizeof(struct container));
  ac->count = 0;
  ac->size = 1;
  ac->a = (int*)malloc(ac->size * sizeof(int));

  return ac;
}

void copy_array(int* to, int* from, int len) {
  int i;
  for (i = len; i-- > 0; ) {
    to[i] = from[i];
  }
}

void maybe_grow_array(array_container ac) {
  int *new_a;
  if (ac->count + 1 >= ac->size) {
    ac->size *= 2;
    new_a = (int*)malloc(ac->size * sizeof(int));
    copy_array(new_a, ac->a, ac->count);
    ac->a = new_a;
  }
}

void add_to_front(array_container ac, int i) {
  maybe_grow_array(ac);

  copy_array(ac->a+1, ac->a, ac->count);
  ac->a[0] = i;
  ac->count++;
}

void add_to_back(array_container ac, int i) {
  maybe_grow_array(ac);

  ac->a[ac->count] = i;
  ac->count++;
}

int remove_from_front(array_container ac) {
  int v;

  v = ac->a[0];
  --ac->count;
  copy_array(ac->a, ac->a+1, ac->count);

  return v;
}

int remove_from_back(array_container ac) {
  --ac->count;
  return ac->a[ac->count];
}


int get_count(array_container ac) {
  return ac->count;
}

int get_value(array_container ac, int i) {
  return ac->a[i];
}

/* ---------------------------------------- */

/* Tests */

void failed() {
  printf("test failed\n");
  exit(1);
}

void check_ptr(void *a, void *b) {
  if (a != b) failed();
}

void check_int(int a, int b) {
  if (a != b) failed();
}

void test() {
  array_container ac;

  ac = make_array_container();
  check_int(get_count(ac), 0);
  add_to_front(ac, 5);
  check_int(get_count(ac), 1);
  check_int(get_value(ac, 0), 5);
  add_to_back(ac, 6);
  check_int(get_count(ac), 2);
  check_int(get_value(ac, 0), 5);
  check_int(get_value(ac, 1), 6);
  add_to_back(ac, 7);
  add_to_front(ac, 4);
  check_int(get_count(ac), 4);
  check_int(get_value(ac, 0), 4);
  check_int(get_value(ac, 1), 5);
  check_int(get_value(ac, 2), 6);
  check_int(get_value(ac, 3), 7);
}

/* ---------------------------------------- */

int main() {
  array_container ac;
  char buffer[256];
  int i, count;

  test();

  ac = make_array_container();
  
  for (; fgets(buffer, 256, stdin); ) {
    add_to_back(ac, atoi(buffer));
  }

  count = get_count(ac);
  for (i = 0; i < count; i++) {
    printf("%d\n", get_value(ac, i));
  }

  return 0;
}
